@@ -149,7 +149,6 @@ void ModemPropertiesTest::testModemProperties()
             }
         }
         QVERIFY(found);
-        found = false;
     }
     QCOMPARE(modemInterface->plugin(), pluginChangedSpy.at(0).at(0).toString());
 
@@ -231,3 +230,5 @@ void ModemPropertiesTest::testModemProperties()
 }
 
 QTEST_MAIN(ModemPropertiesTest)
+
+#include "moc_modempropertiestest.cpp"
